@@ -16,6 +16,7 @@ from .adv_parsers.contact import process_wocontact
 from .adv_parsers.curtain import process_wocurtain
 from .adv_parsers.humidifier import process_wohumidifier
 from .adv_parsers.light_strip import process_wostrip
+from .adv_parsers.lock import process_wolock
 from .adv_parsers.meter import process_wosensorth
 from .adv_parsers.motion import process_wopresence
 from .adv_parsers.plug import process_woplugmini
@@ -94,6 +95,11 @@ SUPPORTED_TYPES: dict[str, SwitchbotSupportedType] = {
         "modelFriendlyName": "Humidifier",
         "func": process_wohumidifier,
     },
+    "o": {
+        "modelName": SwitchbotModel.LOCK,
+        "modelFriendlyName": "Lock",
+        "func": process_wolock,
+    },
 }
 
 
@@ -112,14 +118,20 @@ def parse_advertisement_data(
         if uuid in service_data:
             _service_data = service_data[uuid]
             break
-    if not _service_data:
-        _service_data = list(advertisement_data.service_data.values())[0]
+
     if not _service_data:
         return None
 
     _mfr_data = _mgr_datas[0] if _mgr_datas else None
 
-    data = _parse_data(_service_data, _mfr_data)
+    try:
+        data = _parse_data(_service_data, _mfr_data)
+    except Exception as err:  # pylint: disable=broad-except
+        _LOGGER.exception(
+            "Failed to parse advertisement data: %s: %s", advertisement_data, err
+        )
+        return None
+
     return SwitchBotAdvertisement(device.address, data, device, advertisement_data.rssi)
 
 
